# Print an optspec for argparse to handle cmd's options that are independent of any subcommand.
function __fish_rad_global_optspecs
	string join \n h/help V/version
end

function __fish_rad_needs_command
	# Figure out if the current invocation already has a command.
	set -l cmd (commandline -opc)
	set -e cmd[1]
	argparse -s (__fish_rad_global_optspecs) -- $cmd 2>/dev/null
	or return
	if set -q argv[1]
		# Also print the command, so this can be used to figure out what it is.
		echo $argv[1]
		return 1
	end
	return 0
end

function __fish_rad_using_subcommand
	set -l cmd (__fish_rad_needs_command)
	test -z "$cmd"
	and return 1
	contains -- $cmd[1] $argv
end

complete -c rad -n "__fish_rad_needs_command" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_needs_command" -s V -l version -d 'Print version'
complete -c rad -n "__fish_rad_needs_command" -f -a "auth" -d 'Manage identities and profiles'
complete -c rad -n "__fish_rad_needs_command" -f -a "block" -d 'Block repositories or nodes from being seeded or followed'
complete -c rad -n "__fish_rad_needs_command" -f -a "checkout" -d 'Checkout a repository into the local directory'
complete -c rad -n "__fish_rad_needs_command" -f -a "clean" -d 'Remove all remotes from a repository'
complete -c rad -n "__fish_rad_needs_command" -f -a "clone" -d 'Clone a Radicle repository'
complete -c rad -n "__fish_rad_needs_command" -f -a "cob"
complete -c rad -n "__fish_rad_needs_command" -f -a "config" -d 'Manage your local Radicle configuration'
complete -c rad -n "__fish_rad_needs_command" -f -a "debug" -d 'Write out information to help debug your Radicle node remotely'
complete -c rad -n "__fish_rad_needs_command" -f -a "follow" -d 'Manage node follow policies'
complete -c rad -n "__fish_rad_needs_command" -f -a "fork" -d 'Create a fork of a repository  This command is deprecated and will be removed.  Instead of using `rad fork`, use `git push` to push any references to your own namespace of a Radicle repository. Usually      git push rad main  would suffice to push the default branch (here named \'main\'). '
complete -c rad -n "__fish_rad_needs_command" -f -a "id" -d 'Manage repository identities'
complete -c rad -n "__fish_rad_needs_command" -f -a "inbox" -d 'Manage your Radicle notifications'
complete -c rad -n "__fish_rad_needs_command" -f -a "init" -d 'Initialize a Radicle repository'
complete -c rad -n "__fish_rad_needs_command" -f -a "inspect" -d 'Inspect a Radicle repository'
complete -c rad -n "__fish_rad_needs_command" -f -a "issue" -d 'Manage issues'
complete -c rad -n "__fish_rad_needs_command" -f -a "ls" -d 'List repositories'
complete -c rad -n "__fish_rad_needs_command" -f -a "node" -d 'Control and query the Radicle Node'
complete -c rad -n "__fish_rad_needs_command" -f -a "patch" -d 'Manage patches'
complete -c rad -n "__fish_rad_needs_command" -f -a "path" -d 'Display the Radicle home path'
complete -c rad -n "__fish_rad_needs_command" -f -a "publish" -d 'Publish a repository to the network'
complete -c rad -n "__fish_rad_needs_command" -f -a "remote" -d 'Manage a repository\'s remotes'
complete -c rad -n "__fish_rad_needs_command" -f -a "seed" -d 'Manage repository seeding policies'
complete -c rad -n "__fish_rad_needs_command" -f -a "self" -d 'Show information about your identity and device'
complete -c rad -n "__fish_rad_needs_command" -f -a "stats" -d 'Displays aggregated repository and node metrics'
complete -c rad -n "__fish_rad_needs_command" -f -a "sync" -d 'Sync repositories to the network'
complete -c rad -n "__fish_rad_needs_command" -f -a "unblock" -d 'Unblock repositories or nodes to allow them to be seeded or followed'
complete -c rad -n "__fish_rad_needs_command" -f -a "unfollow" -d 'Unfollow a peer'
complete -c rad -n "__fish_rad_needs_command" -f -a "unseed" -d 'Remove repository seeding policies'
complete -c rad -n "__fish_rad_needs_command" -f -a "watch" -d 'Wait for some state to be updated'
complete -c rad -n "__fish_rad_needs_command" -f -a "version" -d 'Print the version information of the CLI'
complete -c rad -n "__fish_rad_needs_command" -f -a "completion" -d 'Print static completion information for a given shell'
complete -c rad -n "__fish_rad_needs_command" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rad -n "__fish_rad_using_subcommand auth" -l alias -d 'When initializing an identity, sets the node alias' -r
complete -c rad -n "__fish_rad_using_subcommand auth" -l stdin -d 'Read passphrase from stdin'
complete -c rad -n "__fish_rad_using_subcommand auth" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand block" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand checkout" -l remote -d 'The DID of the remote peer to checkout' -r
complete -c rad -n "__fish_rad_using_subcommand checkout" -l no-confirm -d 'Don\'t ask for confirmation during checkout'
complete -c rad -n "__fish_rad_using_subcommand checkout" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand clean" -l no-confirm -d 'Do not ask for confirmation before removal'
complete -c rad -n "__fish_rad_using_subcommand clean" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand clone" -l scope -d 'Follow scope' -r -f -a "all\t''
followed\t''"
complete -c rad -n "__fish_rad_using_subcommand clone" -s s -l seed -d 'Clone from this seed (may be specified multiple times)' -r
complete -c rad -n "__fish_rad_using_subcommand clone" -l timeout -d 'Timeout for fetching repository' -r
complete -c rad -n "__fish_rad_using_subcommand clone" -l signed-refs-feature-level -d ' Perform the fetch using the provided Signed References minimum feature level.  The options for this value provide the following behavior:  `parent`: Only the namespaces that use the parent feature level will be accepted. This prevents graft attacks and replay attacks from occurring. This provides the most security.  `root`: Only the namespaces that use the root feature level will be accepted. This prevents graft attacks from occurring. This option should be only used if you trust the node you are fetching from, and want to bypass security for backwards compatibility.  `none`: All namespaces will be fetched regardless of feature level detected, and provides no security against graft attacks or replay attacks. This option should be only used if you trust the node you are fetching from, and want to bypass security for backwards compatibility. ' -r -f -a "parent\t''
root\t''
none\t''"
complete -c rad -n "__fish_rad_using_subcommand clone" -l bare -d 'Make a bare repository'
complete -c rad -n "__fish_rad_using_subcommand clone" -l no-confirm
complete -c rad -n "__fish_rad_using_subcommand clone" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand cob; and not __fish_seen_subcommand_from create list log migrate show update help" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand cob; and not __fish_seen_subcommand_from create list log migrate show update help" -f -a "create" -d 'Create a new COB of a given type given initial actions'
complete -c rad -n "__fish_rad_using_subcommand cob; and not __fish_seen_subcommand_from create list log migrate show update help" -f -a "list" -d 'List all COBs of a given type'
complete -c rad -n "__fish_rad_using_subcommand cob; and not __fish_seen_subcommand_from create list log migrate show update help" -f -a "log" -d 'Print a log of all raw operations on a COB'
complete -c rad -n "__fish_rad_using_subcommand cob; and not __fish_seen_subcommand_from create list log migrate show update help" -f -a "migrate" -d 'Migrate the COB database to the latest version'
complete -c rad -n "__fish_rad_using_subcommand cob; and not __fish_seen_subcommand_from create list log migrate show update help" -f -a "show" -d 'Print the state of COBs'
complete -c rad -n "__fish_rad_using_subcommand cob; and not __fish_seen_subcommand_from create list log migrate show update help" -f -a "update" -d 'Add actions to a COB'
complete -c rad -n "__fish_rad_using_subcommand cob; and not __fish_seen_subcommand_from create list log migrate show update help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from create" -s r -l repo -d 'Repository ID of the repository to operate on' -r
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from create" -s t -l type -d 'Typename of the object to create' -r
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from create" -s m -l message -d 'Message describing the operation' -r
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from create" -l embed-file -d 'Supply embed of given name via file at given path' -r
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from create" -l embed-hash -d 'Supply embed of given name via object ID of blob' -r
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from create" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from list" -s r -l repo -d 'Repository ID of the repository to operate on' -r
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from list" -s t -l type -d 'Typename of the object(s) to list' -r
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from log" -s r -l repo -d 'Tepository ID of the repository to operate on' -r
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from log" -s t -l type -d 'Typename of the object(s) to show' -r
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from log" -s o -l object -d 'Object ID of the object to log' -r
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from log" -l format -d 'Desired output format' -r -f -a "json\t''
pretty\t''"
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from log" -l from -d 'Object ID of the commit of the operation to start iterating at' -r
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from log" -l until -d 'Object ID of the commit of the operation to stop iterating at' -r
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from log" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from migrate" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from show" -s r -l repo -d 'Repository ID of the repository to operate on' -r
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from show" -s t -l type -d 'Typename of the object(s) to show' -r
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from show" -s o -l object -d 'Object ID(s) of the objects to show' -r
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from show" -l format -d 'Desired output format' -r -f -a "json\t''
pretty\t''"
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from show" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from update" -s r -l repo -d 'Repository ID of the repository to operate on' -r
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from update" -s t -l type -d 'Typename of the object to update' -r
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from update" -s o -l object -d 'Object ID of the object to update' -r
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from update" -l format -d 'Desired output format' -r -f -a "json\t''
pretty\t''"
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from update" -s m -l message -d 'Message describing the operation' -r
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from update" -l embed-file -d 'Supply embed of given name via file at given path' -r
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from update" -l embed-hash -d 'Supply embed of given name via object ID of blob' -r
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from update" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from help" -f -a "create" -d 'Create a new COB of a given type given initial actions'
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from help" -f -a "list" -d 'List all COBs of a given type'
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from help" -f -a "log" -d 'Print a log of all raw operations on a COB'
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from help" -f -a "migrate" -d 'Migrate the COB database to the latest version'
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from help" -f -a "show" -d 'Print the state of COBs'
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from help" -f -a "update" -d 'Add actions to a COB'
complete -c rad -n "__fish_rad_using_subcommand cob; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rad -n "__fish_rad_using_subcommand config; and not __fish_seen_subcommand_from show init edit get schema set unset push remove help" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand config; and not __fish_seen_subcommand_from show init edit get schema set unset push remove help" -f -a "show" -d 'Show the current radicle configuration as JSON (default)'
complete -c rad -n "__fish_rad_using_subcommand config; and not __fish_seen_subcommand_from show init edit get schema set unset push remove help" -f -a "init" -d 'Initialize a new config file'
complete -c rad -n "__fish_rad_using_subcommand config; and not __fish_seen_subcommand_from show init edit get schema set unset push remove help" -f -a "edit" -d 'Open the config in your editor'
complete -c rad -n "__fish_rad_using_subcommand config; and not __fish_seen_subcommand_from show init edit get schema set unset push remove help" -f -a "get" -d 'Get a value from the current configuration'
complete -c rad -n "__fish_rad_using_subcommand config; and not __fish_seen_subcommand_from show init edit get schema set unset push remove help" -f -a "schema" -d 'Prints the JSON Schema of the Radicle configuration'
complete -c rad -n "__fish_rad_using_subcommand config; and not __fish_seen_subcommand_from show init edit get schema set unset push remove help" -f -a "set" -d 'Set a key to a value in the current configuration'
complete -c rad -n "__fish_rad_using_subcommand config; and not __fish_seen_subcommand_from show init edit get schema set unset push remove help" -f -a "unset" -d 'Set a key in the current configuration to `null`'
complete -c rad -n "__fish_rad_using_subcommand config; and not __fish_seen_subcommand_from show init edit get schema set unset push remove help" -f -a "push" -d 'Push a value onto an array, which is identified by the key, in the current configuration'
complete -c rad -n "__fish_rad_using_subcommand config; and not __fish_seen_subcommand_from show init edit get schema set unset push remove help" -f -a "remove" -d 'Remove a value from an array, which is identified by the key, in the current configuration'
complete -c rad -n "__fish_rad_using_subcommand config; and not __fish_seen_subcommand_from show init edit get schema set unset push remove help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rad -n "__fish_rad_using_subcommand config; and __fish_seen_subcommand_from show" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand config; and __fish_seen_subcommand_from init" -l alias -d 'Alias to use for the new configuration' -r
complete -c rad -n "__fish_rad_using_subcommand config; and __fish_seen_subcommand_from init" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand config; and __fish_seen_subcommand_from edit" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand config; and __fish_seen_subcommand_from get" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand config; and __fish_seen_subcommand_from schema" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand config; and __fish_seen_subcommand_from set" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand config; and __fish_seen_subcommand_from unset" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand config; and __fish_seen_subcommand_from push" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand config; and __fish_seen_subcommand_from remove" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand config; and __fish_seen_subcommand_from help" -f -a "show" -d 'Show the current radicle configuration as JSON (default)'
complete -c rad -n "__fish_rad_using_subcommand config; and __fish_seen_subcommand_from help" -f -a "init" -d 'Initialize a new config file'
complete -c rad -n "__fish_rad_using_subcommand config; and __fish_seen_subcommand_from help" -f -a "edit" -d 'Open the config in your editor'
complete -c rad -n "__fish_rad_using_subcommand config; and __fish_seen_subcommand_from help" -f -a "get" -d 'Get a value from the current configuration'
complete -c rad -n "__fish_rad_using_subcommand config; and __fish_seen_subcommand_from help" -f -a "schema" -d 'Prints the JSON Schema of the Radicle configuration'
complete -c rad -n "__fish_rad_using_subcommand config; and __fish_seen_subcommand_from help" -f -a "set" -d 'Set a key to a value in the current configuration'
complete -c rad -n "__fish_rad_using_subcommand config; and __fish_seen_subcommand_from help" -f -a "unset" -d 'Set a key in the current configuration to `null`'
complete -c rad -n "__fish_rad_using_subcommand config; and __fish_seen_subcommand_from help" -f -a "push" -d 'Push a value onto an array, which is identified by the key, in the current configuration'
complete -c rad -n "__fish_rad_using_subcommand config; and __fish_seen_subcommand_from help" -f -a "remove" -d 'Remove a value from an array, which is identified by the key, in the current configuration'
complete -c rad -n "__fish_rad_using_subcommand config; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rad -n "__fish_rad_using_subcommand debug" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand follow" -l alias -d 'Associate an alias to a followed peer' -r
complete -c rad -n "__fish_rad_using_subcommand follow" -s v -l verbose -d 'Verbose output'
complete -c rad -n "__fish_rad_using_subcommand follow" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand fork" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand id; and not __fish_seen_subcommand_from accept reject edit update list show redact help" -l repo -d 'Specify the repository to operate on. Defaults to the current repository' -r
complete -c rad -n "__fish_rad_using_subcommand id; and not __fish_seen_subcommand_from accept reject edit update list show redact help" -l no-confirm -d 'Do not ask for confirmation'
complete -c rad -n "__fish_rad_using_subcommand id; and not __fish_seen_subcommand_from accept reject edit update list show redact help" -s q -l quiet -d 'Suppress output'
complete -c rad -n "__fish_rad_using_subcommand id; and not __fish_seen_subcommand_from accept reject edit update list show redact help" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand id; and not __fish_seen_subcommand_from accept reject edit update list show redact help" -f -a "accept" -d 'Accept a proposed revision to the identity document'
complete -c rad -n "__fish_rad_using_subcommand id; and not __fish_seen_subcommand_from accept reject edit update list show redact help" -f -a "reject" -d 'Reject a proposed revision to the identity document'
complete -c rad -n "__fish_rad_using_subcommand id; and not __fish_seen_subcommand_from accept reject edit update list show redact help" -f -a "edit" -d 'Edit an existing revision to the identity document'
complete -c rad -n "__fish_rad_using_subcommand id; and not __fish_seen_subcommand_from accept reject edit update list show redact help" -f -a "update" -d 'Propose a new revision to the identity document'
complete -c rad -n "__fish_rad_using_subcommand id; and not __fish_seen_subcommand_from accept reject edit update list show redact help" -f -a "list" -d 'Lists all proposed revisions to the identity document'
complete -c rad -n "__fish_rad_using_subcommand id; and not __fish_seen_subcommand_from accept reject edit update list show redact help" -f -a "show" -d 'Show a specific identity proposal'
complete -c rad -n "__fish_rad_using_subcommand id; and not __fish_seen_subcommand_from accept reject edit update list show redact help" -f -a "redact" -d 'Redact a revision'
complete -c rad -n "__fish_rad_using_subcommand id; and not __fish_seen_subcommand_from accept reject edit update list show redact help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from accept" -l repo -d 'Specify the repository to operate on. Defaults to the current repository' -r
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from accept" -l no-confirm -d 'Do not ask for confirmation'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from accept" -s q -l quiet -d 'Suppress output'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from accept" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from reject" -l repo -d 'Specify the repository to operate on. Defaults to the current repository' -r
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from reject" -l no-confirm -d 'Do not ask for confirmation'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from reject" -s q -l quiet -d 'Suppress output'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from reject" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from edit" -l title -d 'Title of the edit' -r
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from edit" -l description -d 'Description of the edit' -r
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from edit" -l repo -d 'Specify the repository to operate on. Defaults to the current repository' -r
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from edit" -l no-confirm -d 'Do not ask for confirmation'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from edit" -s q -l quiet -d 'Suppress output'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from edit" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from update" -l title -d 'Set the title for the new proposal' -r
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from update" -l description -d 'Set the description for the new proposal' -r
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from update" -s d -l delegate -d 'Update the identity by adding a new delegate, identified by their DID' -r
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from update" -s r -l rescind -d 'Update the identity by removing a delegate, identified by their DID' -r
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from update" -l threshold -d 'Update the identity by setting the number of delegates required to accept a revision' -r
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from update" -l visibility -d 'Update the identity by setting the repository\'s visibility to private or public' -r -f -a "private\t''
public\t''"
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from update" -l allow -d 'Update the identity by giving a specific DID access to a private repository' -r
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from update" -l disallow -d 'Update the identity by removing a specific DID\'s access from a private repository' -r
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from update" -l payload -d 'Update the identity by setting metadata in one of the identity payloads' -r
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from update" -l repo -d 'Specify the repository to operate on. Defaults to the current repository' -r
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from update" -l edit -d 'Opens your $EDITOR to edit the JSON contents directly'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from update" -l no-confirm -d 'Do not ask for confirmation'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from update" -s q -l quiet -d 'Suppress output'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from update" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from list" -l repo -d 'Specify the repository to operate on. Defaults to the current repository' -r
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from list" -l no-confirm -d 'Do not ask for confirmation'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from list" -s q -l quiet -d 'Suppress output'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from show" -l repo -d 'Specify the repository to operate on. Defaults to the current repository' -r
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from show" -l no-confirm -d 'Do not ask for confirmation'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from show" -s q -l quiet -d 'Suppress output'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from show" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from redact" -l repo -d 'Specify the repository to operate on. Defaults to the current repository' -r
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from redact" -l no-confirm -d 'Do not ask for confirmation'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from redact" -s q -l quiet -d 'Suppress output'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from redact" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from help" -f -a "accept" -d 'Accept a proposed revision to the identity document'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from help" -f -a "reject" -d 'Reject a proposed revision to the identity document'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from help" -f -a "edit" -d 'Edit an existing revision to the identity document'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from help" -f -a "update" -d 'Propose a new revision to the identity document'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from help" -f -a "list" -d 'Lists all proposed revisions to the identity document'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from help" -f -a "show" -d 'Show a specific identity proposal'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from help" -f -a "redact" -d 'Redact a revision'
complete -c rad -n "__fish_rad_using_subcommand id; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rad -n "__fish_rad_using_subcommand inbox; and not __fish_seen_subcommand_from list show clear help" -l sort-by -d 'Sort by column' -r -f -a "id\t''
timestamp\t''"
complete -c rad -n "__fish_rad_using_subcommand inbox; and not __fish_seen_subcommand_from list show clear help" -l repo -d 'Operate on a given repository [default: cwd]' -r
complete -c rad -n "__fish_rad_using_subcommand inbox; and not __fish_seen_subcommand_from list show clear help" -s r -l reverse -d 'Reverse the list'
complete -c rad -n "__fish_rad_using_subcommand inbox; and not __fish_seen_subcommand_from list show clear help" -l show-unknown -d 'Show any updates that were not recognized'
complete -c rad -n "__fish_rad_using_subcommand inbox; and not __fish_seen_subcommand_from list show clear help" -s a -l all -d 'Operate on all repositories'
complete -c rad -n "__fish_rad_using_subcommand inbox; and not __fish_seen_subcommand_from list show clear help" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand inbox; and not __fish_seen_subcommand_from list show clear help" -f -a "list" -d 'List all items in your inbox'
complete -c rad -n "__fish_rad_using_subcommand inbox; and not __fish_seen_subcommand_from list show clear help" -f -a "show" -d 'Show a notification'
complete -c rad -n "__fish_rad_using_subcommand inbox; and not __fish_seen_subcommand_from list show clear help" -f -a "clear" -d 'Clear notifications'
complete -c rad -n "__fish_rad_using_subcommand inbox; and not __fish_seen_subcommand_from list show clear help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rad -n "__fish_rad_using_subcommand inbox; and __fish_seen_subcommand_from list" -l sort-by -d 'Sort by column' -r -f -a "id\t''
timestamp\t''"
complete -c rad -n "__fish_rad_using_subcommand inbox; and __fish_seen_subcommand_from list" -l repo -d 'Operate on a given repository [default: cwd]' -r
complete -c rad -n "__fish_rad_using_subcommand inbox; and __fish_seen_subcommand_from list" -s r -l reverse -d 'Reverse the list'
complete -c rad -n "__fish_rad_using_subcommand inbox; and __fish_seen_subcommand_from list" -l show-unknown -d 'Show any updates that were not recognized'
complete -c rad -n "__fish_rad_using_subcommand inbox; and __fish_seen_subcommand_from list" -s a -l all -d 'Operate on all repositories'
complete -c rad -n "__fish_rad_using_subcommand inbox; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand inbox; and __fish_seen_subcommand_from show" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand inbox; and __fish_seen_subcommand_from clear" -l repo -d 'Operate on a given repository [default: cwd]' -r
complete -c rad -n "__fish_rad_using_subcommand inbox; and __fish_seen_subcommand_from clear" -s a -l all -d 'Operate on all repositories'
complete -c rad -n "__fish_rad_using_subcommand inbox; and __fish_seen_subcommand_from clear" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand inbox; and __fish_seen_subcommand_from help" -f -a "list" -d 'List all items in your inbox'
complete -c rad -n "__fish_rad_using_subcommand inbox; and __fish_seen_subcommand_from help" -f -a "show" -d 'Show a notification'
complete -c rad -n "__fish_rad_using_subcommand inbox; and __fish_seen_subcommand_from help" -f -a "clear" -d 'Clear notifications'
complete -c rad -n "__fish_rad_using_subcommand inbox; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rad -n "__fish_rad_using_subcommand init" -l name -d 'Name of the repository' -r
complete -c rad -n "__fish_rad_using_subcommand init" -l description -d 'Description of the repository' -r
complete -c rad -n "__fish_rad_using_subcommand init" -l default-branch -d 'The default branch of the repository' -r
complete -c rad -n "__fish_rad_using_subcommand init" -l scope -d 'Repository follow scope' -r -f -a "all\t''
followed\t''"
complete -c rad -n "__fish_rad_using_subcommand init" -l existing -d 'Setup repository as an existing Radicle repository' -r
complete -c rad -n "__fish_rad_using_subcommand init" -l private -d 'Set repository visibility to *private*'
complete -c rad -n "__fish_rad_using_subcommand init" -l public -d 'Set repository visibility to *public*'
complete -c rad -n "__fish_rad_using_subcommand init" -s u -l set-upstream -d 'Setup the upstream of the default branch'
complete -c rad -n "__fish_rad_using_subcommand init" -l setup-signing -d 'Setup the radicle key as a signing key for this repository'
complete -c rad -n "__fish_rad_using_subcommand init" -l no-confirm -d 'Don\'t ask for confirmation during setup'
complete -c rad -n "__fish_rad_using_subcommand init" -l no-seed -d 'Don\'t seed this repository after initializing it'
complete -c rad -n "__fish_rad_using_subcommand init" -s v -l verbose -d 'Verbose mode'
complete -c rad -n "__fish_rad_using_subcommand init" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand inspect" -l delegates -d 'Inspect the repository\'s delegates'
complete -c rad -n "__fish_rad_using_subcommand inspect" -l history -d 'Show the history of the repository identity document'
complete -c rad -n "__fish_rad_using_subcommand inspect" -l identity -d 'Inspect the identity document'
complete -c rad -n "__fish_rad_using_subcommand inspect" -l payload -d 'Inspect the repository\'s identity payload'
complete -c rad -n "__fish_rad_using_subcommand inspect" -l policy -d 'Inspect the repository\'s seeding policy'
complete -c rad -n "__fish_rad_using_subcommand inspect" -l refs -d 'Inspect the repository\'s refs on the local device'
complete -c rad -n "__fish_rad_using_subcommand inspect" -l rid -d 'Return the repository identifier (RID)'
complete -c rad -n "__fish_rad_using_subcommand inspect" -l sigrefs -d 'Inspect the values of `rad/sigrefs` for all remotes of this repository'
complete -c rad -n "__fish_rad_using_subcommand inspect" -l visibility -d 'Inspect the repository\'s visibility'
complete -c rad -n "__fish_rad_using_subcommand inspect" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand issue; and not __fish_seen_subcommand_from assign cache comment edit delete label list open react show state help" -s r -l repo -d 'Operate on the given repository (default: cwd)' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and not __fish_seen_subcommand_from assign cache comment edit delete label list open react show state help" -l assigned -r
complete -c rad -n "__fish_rad_using_subcommand issue; and not __fish_seen_subcommand_from assign cache comment edit delete label list open react show state help" -s q -l quiet -d 'Do not print anything'
complete -c rad -n "__fish_rad_using_subcommand issue; and not __fish_seen_subcommand_from assign cache comment edit delete label list open react show state help" -l no-announce -d 'Do not announce issue changes to the network'
complete -c rad -n "__fish_rad_using_subcommand issue; and not __fish_seen_subcommand_from assign cache comment edit delete label list open react show state help" -l header -d 'Show only the issue header, hiding the comments'
complete -c rad -n "__fish_rad_using_subcommand issue; and not __fish_seen_subcommand_from assign cache comment edit delete label list open react show state help" -s v -l verbose -d 'Enable verbose output'
complete -c rad -n "__fish_rad_using_subcommand issue; and not __fish_seen_subcommand_from assign cache comment edit delete label list open react show state help" -l all
complete -c rad -n "__fish_rad_using_subcommand issue; and not __fish_seen_subcommand_from assign cache comment edit delete label list open react show state help" -l open
complete -c rad -n "__fish_rad_using_subcommand issue; and not __fish_seen_subcommand_from assign cache comment edit delete label list open react show state help" -l closed
complete -c rad -n "__fish_rad_using_subcommand issue; and not __fish_seen_subcommand_from assign cache comment edit delete label list open react show state help" -l solved
complete -c rad -n "__fish_rad_using_subcommand issue; and not __fish_seen_subcommand_from assign cache comment edit delete label list open react show state help" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand issue; and not __fish_seen_subcommand_from assign cache comment edit delete label list open react show state help" -f -a "assign" -d 'Add or delete assignees from an issue'
complete -c rad -n "__fish_rad_using_subcommand issue; and not __fish_seen_subcommand_from assign cache comment edit delete label list open react show state help" -f -a "cache" -d 'Re-cache all issues that can be found in Radicle storage'
complete -c rad -n "__fish_rad_using_subcommand issue; and not __fish_seen_subcommand_from assign cache comment edit delete label list open react show state help" -f -a "comment" -d 'Add a comment to an issue'
complete -c rad -n "__fish_rad_using_subcommand issue; and not __fish_seen_subcommand_from assign cache comment edit delete label list open react show state help" -f -a "edit" -d 'Edit the title and description of an issue'
complete -c rad -n "__fish_rad_using_subcommand issue; and not __fish_seen_subcommand_from assign cache comment edit delete label list open react show state help" -f -a "delete" -d 'Delete an issue'
complete -c rad -n "__fish_rad_using_subcommand issue; and not __fish_seen_subcommand_from assign cache comment edit delete label list open react show state help" -f -a "label" -d 'Add or delete labels from an issue'
complete -c rad -n "__fish_rad_using_subcommand issue; and not __fish_seen_subcommand_from assign cache comment edit delete label list open react show state help" -f -a "list" -d 'List issues, optionally filtering them'
complete -c rad -n "__fish_rad_using_subcommand issue; and not __fish_seen_subcommand_from assign cache comment edit delete label list open react show state help" -f -a "open" -d 'Open a new issue'
complete -c rad -n "__fish_rad_using_subcommand issue; and not __fish_seen_subcommand_from assign cache comment edit delete label list open react show state help" -f -a "react" -d 'Add a reaction emoji to an issue or comment'
complete -c rad -n "__fish_rad_using_subcommand issue; and not __fish_seen_subcommand_from assign cache comment edit delete label list open react show state help" -f -a "show" -d 'Show a specific issue'
complete -c rad -n "__fish_rad_using_subcommand issue; and not __fish_seen_subcommand_from assign cache comment edit delete label list open react show state help" -f -a "state" -d 'Transition the state of an issue'
complete -c rad -n "__fish_rad_using_subcommand issue; and not __fish_seen_subcommand_from assign cache comment edit delete label list open react show state help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from assign" -s a -l add -d 'Add an assignee (may be specified multiple times, takes precedence over `--delete`)' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from assign" -s d -l delete -d 'Delete an assignee (may be specified multiple times)' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from assign" -s r -l repo -d 'Operate on the given repository (default: cwd)' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from assign" -s q -l quiet -d 'Do not print anything'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from assign" -l no-announce -d 'Do not announce issue changes to the network'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from assign" -l header -d 'Show only the issue header, hiding the comments'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from assign" -s v -l verbose -d 'Enable verbose output'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from assign" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from cache" -s r -l repo -d 'Operate on the given repository (default: cwd)' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from cache" -l storage -d 'Operate on storage'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from cache" -s q -l quiet -d 'Do not print anything'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from cache" -l no-announce -d 'Do not announce issue changes to the network'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from cache" -l header -d 'Show only the issue header, hiding the comments'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from cache" -s v -l verbose -d 'Enable verbose output'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from cache" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from comment" -s m -l message -d 'The body of the comment' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from comment" -l reply-to -d 'Optionally, the comment to reply to. If not specified, the comment will be in reply to the issue itself' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from comment" -l edit -d 'Edit a comment by specifying its ID' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from comment" -s r -l repo -d 'Operate on the given repository (default: cwd)' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from comment" -s q -l quiet -d 'Do not print anything'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from comment" -l no-announce -d 'Do not announce issue changes to the network'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from comment" -l header -d 'Show only the issue header, hiding the comments'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from comment" -s v -l verbose -d 'Enable verbose output'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from comment" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from edit" -s t -l title -d 'The new title to set' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from edit" -s d -l description -d 'The new description to set' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from edit" -s r -l repo -d 'Operate on the given repository (default: cwd)' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from edit" -s q -l quiet -d 'Do not print anything'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from edit" -l no-announce -d 'Do not announce issue changes to the network'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from edit" -l header -d 'Show only the issue header, hiding the comments'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from edit" -s v -l verbose -d 'Enable verbose output'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from edit" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from delete" -s r -l repo -d 'Operate on the given repository (default: cwd)' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from delete" -s q -l quiet -d 'Do not print anything'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from delete" -l no-announce -d 'Do not announce issue changes to the network'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from delete" -l header -d 'Show only the issue header, hiding the comments'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from delete" -s v -l verbose -d 'Enable verbose output'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from label" -s a -l add -d 'Add a label (may be specified multiple times, takes precedence over `--delete`)' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from label" -s d -l delete -d 'Delete a label (may be specified multiple times)' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from label" -s r -l repo -d 'Operate on the given repository (default: cwd)' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from label" -s q -l quiet -d 'Do not print anything'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from label" -l no-announce -d 'Do not announce issue changes to the network'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from label" -l header -d 'Show only the issue header, hiding the comments'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from label" -s v -l verbose -d 'Enable verbose output'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from label" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from list" -l assigned -d 'Filter for the list of issues that are assigned to \'<DID>\' (default: me)' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from list" -s r -l repo -d 'Operate on the given repository (default: cwd)' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from list" -l all -d 'List all issues'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from list" -l open -d 'List only open issues (default)'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from list" -l closed -d 'List only closed issues'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from list" -l solved -d 'List only solved issues'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from list" -s q -l quiet -d 'Do not print anything'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from list" -l no-announce -d 'Do not announce issue changes to the network'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from list" -l header -d 'Show only the issue header, hiding the comments'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from list" -s v -l verbose -d 'Enable verbose output'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from open" -s t -l title -d 'The title of the issue' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from open" -s d -l description -d 'The description of the issue' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from open" -l labels -d 'A set of labels to associate with the issue' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from open" -l assignees -d 'A set of DIDs to assign to the issue' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from open" -s r -l repo -d 'Operate on the given repository (default: cwd)' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from open" -s q -l quiet -d 'Do not print anything'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from open" -l no-announce -d 'Do not announce issue changes to the network'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from open" -l header -d 'Show only the issue header, hiding the comments'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from open" -s v -l verbose -d 'Enable verbose output'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from open" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from react" -l emoji -d 'The emoji reaction' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from react" -l to -d 'Optionally react to a comment' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from react" -s r -l repo -d 'Operate on the given repository (default: cwd)' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from react" -s q -l quiet -d 'Do not print anything'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from react" -l no-announce -d 'Do not announce issue changes to the network'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from react" -l header -d 'Show only the issue header, hiding the comments'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from react" -s v -l verbose -d 'Enable verbose output'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from react" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from show" -s r -l repo -d 'Operate on the given repository (default: cwd)' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from show" -s q -l quiet -d 'Do not print anything'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from show" -l no-announce -d 'Do not announce issue changes to the network'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from show" -l header -d 'Show only the issue header, hiding the comments'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from show" -s v -l verbose -d 'Enable verbose output'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from show" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from state" -s r -l repo -d 'Operate on the given repository (default: cwd)' -r
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from state" -l open -d 'Change the state to \'open\''
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from state" -l closed -d 'Change the state to \'closed\''
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from state" -l solved -d 'Change the state to \'solved\''
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from state" -s q -l quiet -d 'Do not print anything'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from state" -l no-announce -d 'Do not announce issue changes to the network'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from state" -l header -d 'Show only the issue header, hiding the comments'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from state" -s v -l verbose -d 'Enable verbose output'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from state" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from help" -f -a "assign" -d 'Add or delete assignees from an issue'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from help" -f -a "cache" -d 'Re-cache all issues that can be found in Radicle storage'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from help" -f -a "comment" -d 'Add a comment to an issue'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from help" -f -a "edit" -d 'Edit the title and description of an issue'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from help" -f -a "delete" -d 'Delete an issue'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from help" -f -a "label" -d 'Add or delete labels from an issue'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from help" -f -a "list" -d 'List issues, optionally filtering them'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from help" -f -a "open" -d 'Open a new issue'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from help" -f -a "react" -d 'Add a reaction emoji to an issue or comment'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from help" -f -a "show" -d 'Show a specific issue'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from help" -f -a "state" -d 'Transition the state of an issue'
complete -c rad -n "__fish_rad_using_subcommand issue; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rad -n "__fish_rad_using_subcommand ls" -l private -d 'Show only private repositories'
complete -c rad -n "__fish_rad_using_subcommand ls" -l public -d 'Show only public repositories'
complete -c rad -n "__fish_rad_using_subcommand ls" -s s -l seeded -d 'Show all seeded repositories'
complete -c rad -n "__fish_rad_using_subcommand ls" -s a -l all -d 'Show all repositories in storage'
complete -c rad -n "__fish_rad_using_subcommand ls" -s v -l verbose -d 'Verbose output'
complete -c rad -n "__fish_rad_using_subcommand ls" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand node; and not __fish_seen_subcommand_from connect config db events routing start logs status inventory debug sessions stop help" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand node; and not __fish_seen_subcommand_from connect config db events routing start logs status inventory debug sessions stop help" -f -a "connect" -d 'Instruct the node to connect to another node'
complete -c rad -n "__fish_rad_using_subcommand node; and not __fish_seen_subcommand_from connect config db events routing start logs status inventory debug sessions stop help" -f -a "config" -d 'Show the config'
complete -c rad -n "__fish_rad_using_subcommand node; and not __fish_seen_subcommand_from connect config db events routing start logs status inventory debug sessions stop help" -f -a "db" -d 'Interact with the node database'
complete -c rad -n "__fish_rad_using_subcommand node; and not __fish_seen_subcommand_from connect config db events routing start logs status inventory debug sessions stop help" -f -a "events" -d 'Watch and print events'
complete -c rad -n "__fish_rad_using_subcommand node; and not __fish_seen_subcommand_from connect config db events routing start logs status inventory debug sessions stop help" -f -a "routing" -d 'Show the routing table'
complete -c rad -n "__fish_rad_using_subcommand node; and not __fish_seen_subcommand_from connect config db events routing start logs status inventory debug sessions stop help" -f -a "start" -d 'Start the node'
complete -c rad -n "__fish_rad_using_subcommand node; and not __fish_seen_subcommand_from connect config db events routing start logs status inventory debug sessions stop help" -f -a "logs" -d 'Show the log'
complete -c rad -n "__fish_rad_using_subcommand node; and not __fish_seen_subcommand_from connect config db events routing start logs status inventory debug sessions stop help" -f -a "status" -d 'Show the status'
complete -c rad -n "__fish_rad_using_subcommand node; and not __fish_seen_subcommand_from connect config db events routing start logs status inventory debug sessions stop help" -f -a "inventory" -d 'Manage the inventory'
complete -c rad -n "__fish_rad_using_subcommand node; and not __fish_seen_subcommand_from connect config db events routing start logs status inventory debug sessions stop help" -f -a "debug" -d 'Show debug information related to the running node'
complete -c rad -n "__fish_rad_using_subcommand node; and not __fish_seen_subcommand_from connect config db events routing start logs status inventory debug sessions stop help" -f -a "sessions" -d 'Show the active sessions of the running node'
complete -c rad -n "__fish_rad_using_subcommand node; and not __fish_seen_subcommand_from connect config db events routing start logs status inventory debug sessions stop help" -f -a "stop" -d 'Stop the node'
complete -c rad -n "__fish_rad_using_subcommand node; and not __fish_seen_subcommand_from connect config db events routing start logs status inventory debug sessions stop help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from connect" -l timeout -d 'How long to wait for the connection to be established' -r
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from connect" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from config" -l addresses -d 'Only show external addresses from the node\'s config'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from config" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from db" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from db" -f -a "exec" -d 'Execute an SQL operation on the local node database'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from db" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from events" -l timeout -d 'How long to wait to receive an event before giving up' -r
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from events" -s n -l count -d 'Exit after <COUNT> events' -r
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from events" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from routing" -l rid -d 'Show the routing table entries for the given RID' -r
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from routing" -l nid -d 'Show the routing table entries for the given NID' -r
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from routing" -l json -d 'Output the routing table as json'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from routing" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from start" -l path -d 'Start node binary at path' -r -F
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from start" -l foreground -d 'Start the node in the foreground'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from start" -s v -l verbose -d 'Verbose output'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from start" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from logs" -l lines -d 'Only show <COUNT> lines of the log' -r
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from logs" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from status" -l only -d 'If node is running, only print the Node ID and exit, otherwise exit with a non-zero exit status' -r -f -a "nid\t''"
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from status" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from inventory" -l nid -d 'List the inventory of the given NID, defaults to `self`' -r
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from inventory" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from debug" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from sessions" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from stop" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from help" -f -a "connect" -d 'Instruct the node to connect to another node'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from help" -f -a "config" -d 'Show the config'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from help" -f -a "db" -d 'Interact with the node database'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from help" -f -a "events" -d 'Watch and print events'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from help" -f -a "routing" -d 'Show the routing table'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from help" -f -a "start" -d 'Start the node'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from help" -f -a "logs" -d 'Show the log'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from help" -f -a "status" -d 'Show the status'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from help" -f -a "inventory" -d 'Manage the inventory'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from help" -f -a "debug" -d 'Show debug information related to the running node'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from help" -f -a "sessions" -d 'Show the active sessions of the running node'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from help" -f -a "stop" -d 'Stop the node'
complete -c rad -n "__fish_rad_using_subcommand node; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -l repo -d 'Operate on the given repository [default: cwd]' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -l authors -r
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -s q -l quiet -d 'Quiet output'
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -l announce -d 'Announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -l no-announce -d 'Do not announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -s v -l verbose -d 'Verbose output'
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -l authored
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -l all
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -l draft
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -l open
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -l merged
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -l archived
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -f -a "list" -d 'List the patches of a repository'
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -f -a "show" -d 'Show a specific patch'
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -f -a "diff" -d 'Show the diff of a specific patch'
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -f -a "archive" -d 'Mark a patch as archived'
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -f -a "update" -d 'Update the metadata of a patch'
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -f -a "checkout" -d 'Checkout a Git branch pointing to the head of a patch revision'
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -f -a "review" -d 'Create a review of a patch revision'
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -f -a "resolve" -d 'Mark a comment of a review as resolved or unresolved'
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -f -a "delete" -d 'Delete a patch'
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -f -a "redact" -d 'Redact a patch revision'
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -f -a "react" -d 'React to a patch or patch revision'
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -f -a "assign" -d 'Add or remove assignees to/from a patch'
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -f -a "label" -d 'Add or remove labels to/from a patch'
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -f -a "ready" -d 'If the patch is marked as a draft, then mark it as open'
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -f -a "edit"
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -f -a "set" -d 'Set an upstream branch for a patch'
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -f -a "comment" -d 'Comment on, reply to, edit, or react to a comment'
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -f -a "cache" -d 'Re-cache the patches'
complete -c rad -n "__fish_rad_using_subcommand patch; and not __fish_seen_subcommand_from list show diff archive update checkout review resolve delete redact react assign label ready edit set comment cache help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from list" -l author -d 'Show only patched where the given user is an author (may be specified multiple times)' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from list" -l repo -d 'Operate on the given repository [default: cwd]' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from list" -l authored -d 'Show only patches that you have authored'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from list" -l all -d 'Show all patches, including draft, merged, and archived patches'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from list" -l draft -d 'Show only draft patches'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from list" -l open -d 'Show only open patches (default)'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from list" -l merged -d 'Show only merged patches'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from list" -l archived -d 'Show only archived patches'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from list" -s q -l quiet -d 'Quiet output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from list" -l announce -d 'Announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from list" -l no-announce -d 'Do not announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from list" -s v -l verbose -d 'Verbose output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from show" -l repo -d 'Operate on the given repository [default: cwd]' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from show" -s p -l patch -d 'Show the diff of the changes in the patch'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from show" -s v -l verbose -d 'Verbose output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from show" -s q -l quiet -d 'Quiet output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from show" -l announce -d 'Announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from show" -l no-announce -d 'Do not announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from show" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from diff" -s r -l revision -d 'The revision to diff' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from diff" -l repo -d 'Operate on the given repository [default: cwd]' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from diff" -s q -l quiet -d 'Quiet output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from diff" -l announce -d 'Announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from diff" -l no-announce -d 'Do not announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from diff" -s v -l verbose -d 'Verbose output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from diff" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from archive" -l repo -d 'Operate on the given repository [default: cwd]' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from archive" -l undo -d 'Unarchive a patch'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from archive" -s q -l quiet -d 'Quiet output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from archive" -l announce -d 'Announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from archive" -l no-announce -d 'Do not announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from archive" -s v -l verbose -d 'Verbose output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from archive" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from update" -s b -l base -d 'Provide a Git revision as the base commit' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from update" -s m -l message -d 'Provide a message (default: prompt)' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from update" -l repo -d 'Operate on the given repository [default: cwd]' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from update" -l no-message -d 'Do not provide a message'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from update" -s q -l quiet -d 'Quiet output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from update" -l announce -d 'Announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from update" -l no-announce -d 'Do not announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from update" -s v -l verbose -d 'Verbose output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from update" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from checkout" -l revision -d 'Checkout the given revision of the patch' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from checkout" -l name -d 'Provide a name for the branch to checkout' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from checkout" -l remote -d 'Provide the git remote to use as the upstream' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from checkout" -l repo -d 'Operate on the given repository [default: cwd]' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from checkout" -s f -l force -d 'Checkout the head of the revision, even if the branch already exists'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from checkout" -s q -l quiet -d 'Quiet output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from checkout" -l announce -d 'Announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from checkout" -l no-announce -d 'Do not announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from checkout" -s v -l verbose -d 'Verbose output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from checkout" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from review" -s r -l revision -d 'The particular revision to review' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from review" -s U -l unified -d 'Generate diffs with <N> lines of context' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from review" -l hunk -d 'Only review a specific hunk' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from review" -s m -l message -d 'Provide a message (default: prompt)' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from review" -l repo -d 'Operate on the given repository [default: cwd]' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from review" -s p -l patch -d 'Review by patch hunks'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from review" -l accept -d 'Accept a patch revision'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from review" -l reject -d 'Reject a patch revision'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from review" -s d -l delete -d 'Delete a review draft'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from review" -l no-message -d 'Do not provide a message'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from review" -s q -l quiet -d 'Quiet output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from review" -l announce -d 'Announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from review" -l no-announce -d 'Do not announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from review" -s v -l verbose -d 'Verbose output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from review" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from resolve" -l review -d 'The review id which the comment is under' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from resolve" -l comment -d 'The comment to (un)resolve' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from resolve" -l repo -d 'Operate on the given repository [default: cwd]' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from resolve" -l unresolve -d 'Unresolve the comment'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from resolve" -s q -l quiet -d 'Quiet output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from resolve" -l announce -d 'Announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from resolve" -l no-announce -d 'Do not announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from resolve" -s v -l verbose -d 'Verbose output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from resolve" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from delete" -l repo -d 'Operate on the given repository [default: cwd]' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from delete" -s q -l quiet -d 'Quiet output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from delete" -l announce -d 'Announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from delete" -l no-announce -d 'Do not announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from delete" -s v -l verbose -d 'Verbose output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from redact" -l repo -d 'Operate on the given repository [default: cwd]' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from redact" -s q -l quiet -d 'Quiet output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from redact" -l announce -d 'Announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from redact" -l no-announce -d 'Do not announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from redact" -s v -l verbose -d 'Verbose output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from redact" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from react" -l emoji -d 'The reaction being used' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from react" -l repo -d 'Operate on the given repository [default: cwd]' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from react" -l undo -d 'Remove the reaction'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from react" -s q -l quiet -d 'Quiet output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from react" -l announce -d 'Announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from react" -l no-announce -d 'Do not announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from react" -s v -l verbose -d 'Verbose output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from react" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from assign" -s a -l add -d 'Add an assignee to the patch (may be specified multiple times)' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from assign" -s d -l delete -d 'Remove an assignee from the patch (may be specified multiple times)' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from assign" -l repo -d 'Operate on the given repository [default: cwd]' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from assign" -s q -l quiet -d 'Quiet output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from assign" -l announce -d 'Announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from assign" -l no-announce -d 'Do not announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from assign" -s v -l verbose -d 'Verbose output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from assign" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from label" -s a -l add -d 'Add a label to the patch (may be specified multiple times)' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from label" -s d -l delete -d 'Remove a label from the patch (may be specified multiple times)' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from label" -l repo -d 'Operate on the given repository [default: cwd]' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from label" -s q -l quiet -d 'Quiet output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from label" -l announce -d 'Announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from label" -l no-announce -d 'Do not announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from label" -s v -l verbose -d 'Verbose output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from label" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from ready" -l repo -d 'Operate on the given repository [default: cwd]' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from ready" -l undo -d 'Convert a patch back to a draft'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from ready" -s q -l quiet -d 'Quiet output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from ready" -l announce -d 'Announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from ready" -l no-announce -d 'Do not announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from ready" -s v -l verbose -d 'Verbose output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from ready" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from edit" -l revision -d 'ID of the patch revision' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from edit" -s m -l message -d 'Provide a message (default: prompt)' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from edit" -l repo -d 'Operate on the given repository [default: cwd]' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from edit" -l no-message -d 'Do not provide a message'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from edit" -s q -l quiet -d 'Quiet output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from edit" -l announce -d 'Announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from edit" -l no-announce -d 'Do not announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from edit" -s v -l verbose -d 'Verbose output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from edit" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from set" -l remote -d 'Provide the git remote to use as the upstream' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from set" -l repo -d 'Operate on the given repository [default: cwd]' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from set" -s q -l quiet -d 'Quiet output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from set" -l announce -d 'Announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from set" -l no-announce -d 'Do not announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from set" -s v -l verbose -d 'Verbose output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from set" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from comment" -s m -l message -d 'Provide a message (default: prompt)' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from comment" -l edit -d 'The comment to edit' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from comment" -l react -d 'The comment to react to' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from comment" -l redact -d 'The comment to redact' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from comment" -l emoji -d 'The emoji to react with' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from comment" -l reply-to -d 'The comment to reply to' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from comment" -l repo -d 'Operate on the given repository [default: cwd]' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from comment" -l no-message -d 'Do not provide a message'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from comment" -l undo -d 'Remove the reaction'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from comment" -s q -l quiet -d 'Quiet output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from comment" -l announce -d 'Announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from comment" -l no-announce -d 'Do not announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from comment" -s v -l verbose -d 'Verbose output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from comment" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from cache" -l repo -d 'Operate on the given repository [default: cwd]' -r
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from cache" -l storage -d 'Re-cache all patches in storage, as opposed to the current repository'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from cache" -s q -l quiet -d 'Quiet output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from cache" -l announce -d 'Announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from cache" -l no-announce -d 'Do not announce changes made to the network'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from cache" -s v -l verbose -d 'Verbose output'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from cache" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from help" -f -a "list" -d 'List the patches of a repository'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from help" -f -a "show" -d 'Show a specific patch'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from help" -f -a "diff" -d 'Show the diff of a specific patch'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from help" -f -a "archive" -d 'Mark a patch as archived'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from help" -f -a "update" -d 'Update the metadata of a patch'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from help" -f -a "checkout" -d 'Checkout a Git branch pointing to the head of a patch revision'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from help" -f -a "review" -d 'Create a review of a patch revision'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from help" -f -a "resolve" -d 'Mark a comment of a review as resolved or unresolved'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from help" -f -a "delete" -d 'Delete a patch'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from help" -f -a "redact" -d 'Redact a patch revision'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from help" -f -a "react" -d 'React to a patch or patch revision'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from help" -f -a "assign" -d 'Add or remove assignees to/from a patch'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from help" -f -a "label" -d 'Add or remove labels to/from a patch'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from help" -f -a "ready" -d 'If the patch is marked as a draft, then mark it as open'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from help" -f -a "edit"
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from help" -f -a "set" -d 'Set an upstream branch for a patch'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from help" -f -a "comment" -d 'Comment on, reply to, edit, or react to a comment'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from help" -f -a "cache" -d 'Re-cache the patches'
complete -c rad -n "__fish_rad_using_subcommand patch; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rad -n "__fish_rad_using_subcommand path" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand publish" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand remote; and not __fish_seen_subcommand_from add rm list help" -l all
complete -c rad -n "__fish_rad_using_subcommand remote; and not __fish_seen_subcommand_from add rm list help" -l tracked
complete -c rad -n "__fish_rad_using_subcommand remote; and not __fish_seen_subcommand_from add rm list help" -l untracked
complete -c rad -n "__fish_rad_using_subcommand remote; and not __fish_seen_subcommand_from add rm list help" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand remote; and not __fish_seen_subcommand_from add rm list help" -f -a "add" -d 'Add a Git remote for the provided NID'
complete -c rad -n "__fish_rad_using_subcommand remote; and not __fish_seen_subcommand_from add rm list help" -f -a "rm" -d 'Remove the Git remote identified by REMOTE'
complete -c rad -n "__fish_rad_using_subcommand remote; and not __fish_seen_subcommand_from add rm list help" -f -a "list" -d 'List the stored remotes'
complete -c rad -n "__fish_rad_using_subcommand remote; and not __fish_seen_subcommand_from add rm list help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rad -n "__fish_rad_using_subcommand remote; and __fish_seen_subcommand_from add" -s n -l name -d 'Override the name of the Git remote' -r
complete -c rad -n "__fish_rad_using_subcommand remote; and __fish_seen_subcommand_from add" -l fetch -d 'Fetch the remote from local storage (default)'
complete -c rad -n "__fish_rad_using_subcommand remote; and __fish_seen_subcommand_from add" -l no-fetch -d 'Do not fetch the remote from local storage'
complete -c rad -n "__fish_rad_using_subcommand remote; and __fish_seen_subcommand_from add" -l sync -d 'Sync the remote refs from the network (default)'
complete -c rad -n "__fish_rad_using_subcommand remote; and __fish_seen_subcommand_from add" -l no-sync -d 'Do not sync the remote refs from the network'
complete -c rad -n "__fish_rad_using_subcommand remote; and __fish_seen_subcommand_from add" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand remote; and __fish_seen_subcommand_from rm" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand remote; and __fish_seen_subcommand_from list" -l all -d 'Show all remotes in both the Radicle storage and the working copy'
complete -c rad -n "__fish_rad_using_subcommand remote; and __fish_seen_subcommand_from list" -l tracked -d 'Show all remotes that are listed in the working copy'
complete -c rad -n "__fish_rad_using_subcommand remote; and __fish_seen_subcommand_from list" -l untracked -d 'Show all remotes that are listed in the Radicle storage'
complete -c rad -n "__fish_rad_using_subcommand remote; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand remote; and __fish_seen_subcommand_from help" -f -a "add" -d 'Add a Git remote for the provided NID'
complete -c rad -n "__fish_rad_using_subcommand remote; and __fish_seen_subcommand_from help" -f -a "rm" -d 'Remove the Git remote identified by REMOTE'
complete -c rad -n "__fish_rad_using_subcommand remote; and __fish_seen_subcommand_from help" -f -a "list" -d 'List the stored remotes'
complete -c rad -n "__fish_rad_using_subcommand remote; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rad -n "__fish_rad_using_subcommand seed" -l from -d 'Fetch from the given node (may be specified multiple times)' -r
complete -c rad -n "__fish_rad_using_subcommand seed" -s t -l timeout -d 'Fetch timeout in seconds' -r
complete -c rad -n "__fish_rad_using_subcommand seed" -l scope -d 'Peer follow scope for this repository' -r -f -a "all\t''
followed\t''"
complete -c rad -n "__fish_rad_using_subcommand seed" -l fetch -d 'Fetch repository after updating seeding policy'
complete -c rad -n "__fish_rad_using_subcommand seed" -l no-fetch -d 'Do not fetch repository after updating seeding policy'
complete -c rad -n "__fish_rad_using_subcommand seed" -s v -l verbose -d 'Verbose output'
complete -c rad -n "__fish_rad_using_subcommand seed" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand self" -l did -d 'Show your DID'
complete -c rad -n "__fish_rad_using_subcommand self" -l alias -d 'Show your Node alias'
complete -c rad -n "__fish_rad_using_subcommand self" -l nid -d 'Show your Node identifier'
complete -c rad -n "__fish_rad_using_subcommand self" -l home -d 'Show your Radicle home'
complete -c rad -n "__fish_rad_using_subcommand self" -l config -d 'Show the location of your configuration file'
complete -c rad -n "__fish_rad_using_subcommand self" -l ssh-key -d 'Show your public key in OpenSSH format'
complete -c rad -n "__fish_rad_using_subcommand self" -l ssh-fingerprint -d 'Show your public key fingerprint in OpenSSH format'
complete -c rad -n "__fish_rad_using_subcommand self" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand stats" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand sync; and not __fish_seen_subcommand_from status help" -l seed -d 'Synchronize with the given node (may be specified multiple times)' -r
complete -c rad -n "__fish_rad_using_subcommand sync; and not __fish_seen_subcommand_from status help" -s t -l timeout -d 'How long to wait while synchronizing' -r
complete -c rad -n "__fish_rad_using_subcommand sync; and not __fish_seen_subcommand_from status help" -s r -l replicas -d 'Synchronize with a specific number of seeds' -r
complete -c rad -n "__fish_rad_using_subcommand sync; and not __fish_seen_subcommand_from status help" -l max-replicas -d 'Synchronize with an upper bound number of seeds' -r
complete -c rad -n "__fish_rad_using_subcommand sync; and not __fish_seen_subcommand_from status help" -l signed-refs-feature-level -d ' Perform the fetch using the provided Signed References minimum feature level.  The options for this value provide the following behavior:  `parent`: Only the namespaces that use the parent feature level will be accepted. This prevents graft attacks and replay attacks from occurring. This provides the most security.  `root`: Only the namespaces that use the root feature level will be accepted. This prevents graft attacks from occurring. This option should be only used if you trust the node you are fetching from, and want to bypass security for backwards compatibility.  `none`: All namespaces will be fetched regardless of feature level detected, and provides no security against graft attacks or replay attacks. This option should be only used if you trust the node you are fetching from, and want to bypass security for backwards compatibility. ' -r -f -a "parent\t''
root\t''
none\t''"
complete -c rad -n "__fish_rad_using_subcommand sync; and not __fish_seen_subcommand_from status help" -s f -l fetch -d 'Enable fetching [default: true]'
complete -c rad -n "__fish_rad_using_subcommand sync; and not __fish_seen_subcommand_from status help" -s a -l announce -d 'Enable announcing [default: true]'
complete -c rad -n "__fish_rad_using_subcommand sync; and not __fish_seen_subcommand_from status help" -s i -l inventory -d 'Enable announcing inventory [default: false]'
complete -c rad -n "__fish_rad_using_subcommand sync; and not __fish_seen_subcommand_from status help" -l debug -d 'Enable debug information when synchronizing'
complete -c rad -n "__fish_rad_using_subcommand sync; and not __fish_seen_subcommand_from status help" -s v -l verbose -d 'Enable verbose information when synchronizing'
complete -c rad -n "__fish_rad_using_subcommand sync; and not __fish_seen_subcommand_from status help" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand sync; and not __fish_seen_subcommand_from status help" -a "status" -d 'Display the sync status of a repository'
complete -c rad -n "__fish_rad_using_subcommand sync; and not __fish_seen_subcommand_from status help" -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rad -n "__fish_rad_using_subcommand sync; and __fish_seen_subcommand_from status" -l sort-by -d 'Sort the table by column' -r -f -a "nid\t'The NID of the entry'
alias\t'The alias of the entry'
status\t'The status of the entry'"
complete -c rad -n "__fish_rad_using_subcommand sync; and __fish_seen_subcommand_from status" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand sync; and __fish_seen_subcommand_from help" -f -a "status" -d 'Display the sync status of a repository'
complete -c rad -n "__fish_rad_using_subcommand sync; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rad -n "__fish_rad_using_subcommand unblock" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand unfollow" -s v -l verbose -d 'Verbose output'
complete -c rad -n "__fish_rad_using_subcommand unfollow" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand unseed" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand watch" -l repo -d 'The repository to watch, defaults to `rad .`' -r
complete -c rad -n "__fish_rad_using_subcommand watch" -s r -l refstr -d 'The fully-qualified Git reference (branch, tag, etc.) to watch' -r
complete -c rad -n "__fish_rad_using_subcommand watch" -s t -l target -d 'The target OID (commit hash) that when reached, will cause the command to exit' -r
complete -c rad -n "__fish_rad_using_subcommand watch" -s n -l node -d 'The namespace under which this reference exists, defaults to the profiles\' NID' -r
complete -c rad -n "__fish_rad_using_subcommand watch" -s i -l interval -d 'How often, in milliseconds, to check the reference target' -r
complete -c rad -n "__fish_rad_using_subcommand watch" -l timeout -d 'Timeout, in milliseconds' -r
complete -c rad -n "__fish_rad_using_subcommand watch" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rad -n "__fish_rad_using_subcommand version" -l json -d 'Print the version information in JSON format'
complete -c rad -n "__fish_rad_using_subcommand version" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand version" -s V -l version -d 'Print version'
complete -c rad -n "__fish_rad_using_subcommand completion" -s h -l help -d 'Print help'
complete -c rad -n "__fish_rad_using_subcommand completion" -s V -l version -d 'Print version'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "auth" -d 'Manage identities and profiles'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "block" -d 'Block repositories or nodes from being seeded or followed'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "checkout" -d 'Checkout a repository into the local directory'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "clean" -d 'Remove all remotes from a repository'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "clone" -d 'Clone a Radicle repository'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "cob"
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "config" -d 'Manage your local Radicle configuration'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "debug" -d 'Write out information to help debug your Radicle node remotely'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "follow" -d 'Manage node follow policies'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "fork" -d 'Create a fork of a repository  This command is deprecated and will be removed.  Instead of using `rad fork`, use `git push` to push any references to your own namespace of a Radicle repository. Usually      git push rad main  would suffice to push the default branch (here named \'main\'). '
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "id" -d 'Manage repository identities'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "inbox" -d 'Manage your Radicle notifications'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "init" -d 'Initialize a Radicle repository'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "inspect" -d 'Inspect a Radicle repository'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "issue" -d 'Manage issues'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "ls" -d 'List repositories'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "node" -d 'Control and query the Radicle Node'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "patch" -d 'Manage patches'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "path" -d 'Display the Radicle home path'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "publish" -d 'Publish a repository to the network'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "remote" -d 'Manage a repository\'s remotes'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "seed" -d 'Manage repository seeding policies'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "self" -d 'Show information about your identity and device'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "stats" -d 'Displays aggregated repository and node metrics'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "sync" -d 'Sync repositories to the network'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "unblock" -d 'Unblock repositories or nodes to allow them to be seeded or followed'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "unfollow" -d 'Unfollow a peer'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "unseed" -d 'Remove repository seeding policies'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "watch" -d 'Wait for some state to be updated'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "version" -d 'Print the version information of the CLI'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "completion" -d 'Print static completion information for a given shell'
complete -c rad -n "__fish_rad_using_subcommand help; and not __fish_seen_subcommand_from auth block checkout clean clone cob config debug follow fork id inbox init inspect issue ls node patch path publish remote seed self stats sync unblock unfollow unseed watch version completion help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from cob" -f -a "create" -d 'Create a new COB of a given type given initial actions'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from cob" -f -a "list" -d 'List all COBs of a given type'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from cob" -f -a "log" -d 'Print a log of all raw operations on a COB'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from cob" -f -a "migrate" -d 'Migrate the COB database to the latest version'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from cob" -f -a "show" -d 'Print the state of COBs'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from cob" -f -a "update" -d 'Add actions to a COB'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from config" -f -a "show" -d 'Show the current radicle configuration as JSON (default)'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from config" -f -a "init" -d 'Initialize a new config file'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from config" -f -a "edit" -d 'Open the config in your editor'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from config" -f -a "get" -d 'Get a value from the current configuration'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from config" -f -a "schema" -d 'Prints the JSON Schema of the Radicle configuration'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from config" -f -a "set" -d 'Set a key to a value in the current configuration'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from config" -f -a "unset" -d 'Set a key in the current configuration to `null`'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from config" -f -a "push" -d 'Push a value onto an array, which is identified by the key, in the current configuration'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from config" -f -a "remove" -d 'Remove a value from an array, which is identified by the key, in the current configuration'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from id" -f -a "accept" -d 'Accept a proposed revision to the identity document'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from id" -f -a "reject" -d 'Reject a proposed revision to the identity document'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from id" -f -a "edit" -d 'Edit an existing revision to the identity document'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from id" -f -a "update" -d 'Propose a new revision to the identity document'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from id" -f -a "list" -d 'Lists all proposed revisions to the identity document'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from id" -f -a "show" -d 'Show a specific identity proposal'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from id" -f -a "redact" -d 'Redact a revision'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from inbox" -f -a "list" -d 'List all items in your inbox'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from inbox" -f -a "show" -d 'Show a notification'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from inbox" -f -a "clear" -d 'Clear notifications'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from issue" -f -a "assign" -d 'Add or delete assignees from an issue'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from issue" -f -a "cache" -d 'Re-cache all issues that can be found in Radicle storage'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from issue" -f -a "comment" -d 'Add a comment to an issue'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from issue" -f -a "edit" -d 'Edit the title and description of an issue'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from issue" -f -a "delete" -d 'Delete an issue'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from issue" -f -a "label" -d 'Add or delete labels from an issue'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from issue" -f -a "list" -d 'List issues, optionally filtering them'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from issue" -f -a "open" -d 'Open a new issue'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from issue" -f -a "react" -d 'Add a reaction emoji to an issue or comment'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from issue" -f -a "show" -d 'Show a specific issue'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from issue" -f -a "state" -d 'Transition the state of an issue'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from node" -f -a "connect" -d 'Instruct the node to connect to another node'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from node" -f -a "config" -d 'Show the config'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from node" -f -a "db" -d 'Interact with the node database'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from node" -f -a "events" -d 'Watch and print events'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from node" -f -a "routing" -d 'Show the routing table'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from node" -f -a "start" -d 'Start the node'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from node" -f -a "logs" -d 'Show the log'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from node" -f -a "status" -d 'Show the status'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from node" -f -a "inventory" -d 'Manage the inventory'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from node" -f -a "debug" -d 'Show debug information related to the running node'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from node" -f -a "sessions" -d 'Show the active sessions of the running node'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from node" -f -a "stop" -d 'Stop the node'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from patch" -f -a "list" -d 'List the patches of a repository'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from patch" -f -a "show" -d 'Show a specific patch'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from patch" -f -a "diff" -d 'Show the diff of a specific patch'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from patch" -f -a "archive" -d 'Mark a patch as archived'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from patch" -f -a "update" -d 'Update the metadata of a patch'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from patch" -f -a "checkout" -d 'Checkout a Git branch pointing to the head of a patch revision'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from patch" -f -a "review" -d 'Create a review of a patch revision'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from patch" -f -a "resolve" -d 'Mark a comment of a review as resolved or unresolved'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from patch" -f -a "delete" -d 'Delete a patch'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from patch" -f -a "redact" -d 'Redact a patch revision'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from patch" -f -a "react" -d 'React to a patch or patch revision'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from patch" -f -a "assign" -d 'Add or remove assignees to/from a patch'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from patch" -f -a "label" -d 'Add or remove labels to/from a patch'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from patch" -f -a "ready" -d 'If the patch is marked as a draft, then mark it as open'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from patch" -f -a "edit"
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from patch" -f -a "set" -d 'Set an upstream branch for a patch'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from patch" -f -a "comment" -d 'Comment on, reply to, edit, or react to a comment'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from patch" -f -a "cache" -d 'Re-cache the patches'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from remote" -f -a "add" -d 'Add a Git remote for the provided NID'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from remote" -f -a "rm" -d 'Remove the Git remote identified by REMOTE'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from remote" -f -a "list" -d 'List the stored remotes'
complete -c rad -n "__fish_rad_using_subcommand help; and __fish_seen_subcommand_from sync" -f -a "status" -d 'Display the sync status of a repository'
